@@ -4,25 +4,22 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
-
-
-import pickle
 import os
+import pickle
 
-from lib.config_system import get_config
 from config import MY_TRANSACTION_PATH
-
+from lib.config_system import get_config
 from transactions.get_my_transaction import GetMyTransaction
+from transactions.save_my_transaction import SaveMyTransaction
 
 
-def SavetoMyTransaction(tx):
+def SavetoMyTransaction(tx, validated=False):
     """
     Saves the transaction to the transaction db.
     """
 
     currently_list = GetMyTransaction()
-    currently_list.append(tx)
+    tx_list = [tx, validated]
+    currently_list.append(tx_list)
 
-    os.chdir(get_config()["main_folder"])
-    with open(MY_TRANSACTION_PATH, "wb") as my_transaction_file:
-        pickle.dump(currently_list, my_transaction_file, protocol=2)
+    SaveMyTransaction(currently_list)
